@@ -12,15 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Exceptions specifying why a request was malformed"""
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Set
-from typing import Tuple
-from typing import Type
-from typing import TYPE_CHECKING
-from typing import Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Set, Tuple, Type, Union
 
 if TYPE_CHECKING:  # pragma: no cover
     from adorn.data.parameter import Parameter
@@ -83,7 +75,7 @@ class TypeCheckError(Exception):
         return self.to_str()
 
     def __eq__(self, other) -> bool:
-        if type(self) != type(other):
+        if type(self) != type(other):  # noqa: E721
             return False
         return all(
             [
@@ -542,7 +534,7 @@ class UserDictError(TypeCheckError):
         super().__init__(target_cls, msg, child=None, obj=obj)
 
     def __eq__(self, other) -> bool:
-        if type(self) != type(other):
+        if type(self) != type(other):  # noqa: E721
             return False
         return all(
             [
