@@ -19,11 +19,10 @@ import zlib
 from collections import OrderedDict
 from collections.abc import MutableMapping
 from os import PathLike
-from typing import Any
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Union
+from typing import Any, Dict, List, Optional, Union
+
+import tomli
+import yaml
 
 from adorn.exception.configuration_error import ConfigurationError
 
@@ -161,15 +160,14 @@ class Params(MutableMapping):
             try:
                 value = self.params.pop(key)
             except KeyError:
-                msg = f'key "{key}" is required'
+                msg = f"key {key!r} is required"
                 if self.history:
-                    msg += f' at location "{self.history}"'
+                    msg += f" at location {self.history!r}"
                 raise ConfigurationError(msg) from KeyError
         else:
             value = self.params.pop(key, default)
 
         if keep_as_dict or _is_dict_free(value):
-            logger.info(f"{self.history}{key} = {value}")
             return value
         else:
             return self._check_is_dict(key, value)
@@ -272,7 +270,7 @@ class Params(MutableMapping):
         return value
 
     def as_dict(
-        self, quiet: bool = False, infer_type_and_cast: bool = False
+        self, quiet: bool = True, infer_type_and_cast: bool = False
     ) -> Dict[str, Any]:
         """Sometimes we need to just represent the parameters as a dict.
 
@@ -385,10 +383,21 @@ class Params(MutableMapping):
 
         Returns:
             Params: content of the file wrapped in a ``Params``
-        """
+        """  # noqa: DAR401
         params_file = str(params_file)
-        with open(params_file) as file_handle:
-            file_dict = json.loads(file_handle.read())
+        file_dict = None
+        if params_file.endswith("json"):
+            with open(params_file) as file_handle:
+                file_dict = json.loads(file_handle.read())
+        elif params_file.endswith("yaml"):
+            with open(params_file) as file_handle:
+                file_dict = yaml.safe_load(file_handle)
+        elif params_file.endswith("toml"):
+            with open(params_file, "rb") as file_handle:
+                file_dict = tomli.load(file_handle)
+
+        if file_dict is None:
+            raise Exception("Only supported file formats are json, yaml and toml")
         return cls(file_dict)
 
     def to_file(self, params_file: str) -> None:
