@@ -15,20 +15,22 @@
 import inspect
 import logging
 from collections import defaultdict
-from typing import _GenericAlias
-from typing import Any
-from typing import Callable
-from typing import cast
-from typing import ClassVar
-from typing import DefaultDict
-from typing import Dict
-from typing import List
-from typing import Optional
-from typing import Tuple
-from typing import Type
-from typing import TYPE_CHECKING
-from typing import TypeVar
-from typing import Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    ClassVar,
+    DefaultDict,
+    Dict,
+    List,
+    Optional,
+    Tuple,
+    Type,
+    TypeVar,
+    Union,
+    _GenericAlias,
+    cast,
+)
 
 if TYPE_CHECKING:  # pragma: no cover
     from adorn.orchestrator.orchestrator import Orchestrator
@@ -100,7 +102,7 @@ class Complex(Unit):
 
     @classmethod
     def register(
-        cls: Type[_ComplexT], name: Optional[str]
+        cls: Type[_ComplexT], name: Optional[str], exist_ok: bool = False
     ) -> Callable[[Type[_T]], Type[_T]]:
         """Decorator that adds a class to the class hierarchy
 
@@ -109,6 +111,8 @@ class Complex(Unit):
                 ``None``, then the class is both a child of another ``Complex`` type
                 and a parent of other ``Complex`` type(s), but cannot be
                 instantiated
+            exist_ok (bool): if ``True``, then `name` is allowed to already be in the
+                `_registry`
 
         Returns:
             Callable[[Type[_T]], Type[_T]]: funcion that adds the decorated type
@@ -120,7 +124,7 @@ class Complex(Unit):
         def add_subclass_to_registry(subclass: Type[_T]) -> Type[_T]:
             # Add to registry, raise an error if key has already been used.
             if name is not None:
-                if name in registry:
+                if not exist_ok and name in registry:
                     message = (
                         f"Cannot register {name} as {cls.__name__}; "
                         f"name already in use for {registry[name].__name__}"
