@@ -15,18 +15,20 @@
 import collections
 from copy import deepcopy
 from inspect import isclass
-from typing import _GenericAlias
-from typing import Any
-from typing import Dict
-from typing import Iterable
-from typing import List
-from typing import Mapping
-from typing import Optional
-from typing import Set
-from typing import Tuple
-from typing import Type
-from typing import TYPE_CHECKING
-from typing import Union
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Mapping,
+    Optional,
+    Set,
+    Tuple,
+    Type,
+    Union,
+    _GenericAlias,
+)
 
 if TYPE_CHECKING:  # pragma: no cover
     from adorn.orchestrator.orchestrator import Orchestrator
@@ -246,7 +248,7 @@ class Int(BuiltIn):
                 the reason why the ``obj`` didn't pass the additional checks,
                 otherwise ``None``
         """
-        if type(obj) == bool:
+        if type(obj) == bool:  # noqa: E721
             return WrongTypeError(int, obj)
 
 
@@ -500,7 +502,9 @@ class Ruple(Wrapper):
                 by ``target_cls``
         """
         args = getattr(target_cls, "__args__", [])
-        return tuple(orchestrator.from_obj(i, j) for i, j in zip(args, obj))
+        return tuple(
+            orchestrator.from_obj(i, j) for i, j in zip(args, obj)  # noqa: B905
+        )
 
     @classmethod
     def _type_check(
@@ -537,7 +541,8 @@ class Ruple(Wrapper):
             if len(target_args) != len(obj):
                 return TupleArgLenError(target_cls, obj)
             list_checks = [
-                orchestrator.type_check(i, j) for i, j in zip(target_args, obj)
+                orchestrator.type_check(i, j)
+                for i, j in zip(target_args, obj)  # noqa: B905
             ]
             relevant_checks = [
                 (en, i) for en, i in enumerate(list_checks) if i is not None
